Package: sodium
Type: Package
Title: A Modern and Easy-to-Use Crypto Library
Version: 1.4.0
Authors@R: person("Jeroen", "Ooms", role = c("aut", "cre"), email = "jeroenooms@gmail.com",
    comment = c(ORCID = "0000-0002-4035-0289"))
Description: Bindings to 'libsodium' <https://doc.libsodium.org/>: a modern, 
    easy-to-use software library for encryption, decryption, signatures, password
    hashing and more. Sodium uses curve25519, a state-of-the-art Diffie-Hellman 
    function by Daniel Bernstein, which has become very popular after it was 
    discovered that the NSA had backdoored Dual EC DRBG.
License: MIT + file LICENSE
URL: https://docs.ropensci.org/sodium/ https://github.com/r-lib/sodium
BugReports: https://github.com/r-lib/sodium/issues
SystemRequirements: libsodium (>= 1.0.3)
VignetteBuilder: knitr
Suggests: knitr, rmarkdown
RoxygenNote: 7.2.3
NeedsCompilation: yes
Packaged: 2024-12-16 14:16:42 UTC; jeroen
Author: Jeroen Ooms [aut, cre] (<https://orcid.org/0000-0002-4035-0289>)
Maintainer: Jeroen Ooms <jeroenooms@gmail.com>
Repository: CRAN
Date/Publication: 2024-12-16 15:00:05 UTC
Built: R 4.6.0; x86_64-apple-darwin20; 2026-04-26 11:16:32 UTC; unix
Archs: sodium.so.dSYM
