# Generated by roxygen2: do not edit by hand

export(argon2)
export(auth_decrypt)
export(auth_encrypt)
export(bin2hex)
export(chacha20)
export(data_decrypt)
export(data_encrypt)
export(data_tag)
export(diffie_hellman)
export(hash)
export(hex2bin)
export(keygen)
export(password_store)
export(password_verify)
export(pubkey)
export(random)
export(salsa20)
export(scrypt)
export(sha256)
export(sha512)
export(shorthash)
export(sig_keygen)
export(sig_pubkey)
export(sig_sign)
export(sig_verify)
export(simple_decrypt)
export(simple_encrypt)
export(xchacha20)
export(xsalsa20)
useDynLib(sodium,R_auth_sha256)
useDynLib(sodium,R_auth_sha512)
useDynLib(sodium,R_crypto_generichash)
useDynLib(sodium,R_crypto_secret_auth)
useDynLib(sodium,R_crypto_secret_decrypt)
useDynLib(sodium,R_crypto_secret_encrypt)
useDynLib(sodium,R_crypto_secret_verify)
useDynLib(sodium,R_crypto_shorthash)
useDynLib(sodium,R_diffie_hellman)
useDynLib(sodium,R_keygen)
useDynLib(sodium,R_password_hash)
useDynLib(sodium,R_password_verify)
useDynLib(sodium,R_pubkey)
useDynLib(sodium,R_pwhash)
useDynLib(sodium,R_pwhash_argon2)
useDynLib(sodium,R_randombytes_buf)
useDynLib(sodium,R_seal_box)
useDynLib(sodium,R_seal_open)
useDynLib(sodium,R_secure_recv)
useDynLib(sodium,R_secure_send)
useDynLib(sodium,R_sha256)
useDynLib(sodium,R_sha512)
useDynLib(sodium,R_sig_keygen)
useDynLib(sodium,R_sig_pubkey)
useDynLib(sodium,R_sig_sign)
useDynLib(sodium,R_sig_verify)
useDynLib(sodium,R_sodium_bin2hex)
useDynLib(sodium,R_sodium_hex2bin)
useDynLib(sodium,R_stream_chacha20)
useDynLib(sodium,R_stream_salsa20)
useDynLib(sodium,R_stream_xchacha20)
useDynLib(sodium,R_stream_xsalsa20)
useDynLib(sodium,R_xor)
